from pymongo import MongoClient


class mongodbDAL:
    def __init__(self, db_name):
        self.connection_string = "mongodb+srv://ycipriani:1212@cluster0.ey0sv.mongodb.net/Tx?retryWrites=true&w=majority"
        self.client = MongoClient(self.connection_string)
        self.db = self.client[db_name]
        self.collection_names = self.db.list_collection_names()

    def find_file_by_collection(self, file_name: str, file_location: str) -> bool:
        collection = self.db.get_collection(file_location).find()
        for item in collection:
            if file_name == item["file_name"]:
                return True
        return False

    def find_file_in_collection(self, file_name) -> bool:
        for collection_name in self.collection_names:
            collection = self.db.get_collection(collection_name).find()
            for item in collection:
                if file_name == item["file_name"]:
                    return True
        return False

    def move_file(self, file_name, old_location, new_location):
        if self.find_file_by_collection(file_name, old_location):
            old_collection = self.db.get_collection(old_location)
            old_collection.delete_one({'file_name': file_name})
            new_collection = self.db.get_collection(new_location)
            new_collection.insert_one({'file_name': file_name, 'file_location': new_location})



import socket
import sys
from contextlib import closing

port_file_path = sys.path[0].replace("utils", "").replace("/base_library.zip", "") + "port.txt"

def read_port_from_file():
    file = open(
        port_file_path,
        "r",
    )
    lines = file.read().splitlines()
    return lines[-1]


def read_all_ports_from_file():
    file = open(
        port_file_path,
        "r",
    )
    return file.read().splitlines()


def write_port_to_file(port):
    file = open(
        port_file_path,
        "a",
    )
    file.write("\n" + str(port))


def find_free_port():
    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
        s.bind(("", 0))
        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        return s.getsockname()[1]



import threading
import time
import datetime
from tkinter import *
from threading import Thread
import tkinter as tk
import sys

import os
import requests

from filesharing.common.globals import credentials, admin_email
from filesharing.common.logger import get_logger
from filesharing.app import start_app

from tkinter import messagebox

from filesharing.utils.current_time import (
    get_current_date_and_time,
    get_seconds_diff,
    write_service_started_time_to_file,
    write_number_of_checks_made,
    number_of_checks_made,
    service_started_time,
)
from filesharing.utils.notifications import (
    send_email,
    log_syslog,
    start_snmp_trap_receiver,
    send_snmp_trap,
)
from filesharing.utils.port import read_port_from_file

lock = threading.Lock()

log_file_path = sys.path[0].replace("screens", "").replace("/base_library.zip", "") + "/logs/demo.log"

def login(my_request):
    global log
    log = get_logger()
    global thread
    global thread1
    global login_screen
    login_screen = Tk()
    login_screen.title("Login")
    login_screen.eval(
        "tk::PlaceWindow %s center"
        % login_screen.winfo_pathname(login_screen.winfo_id())
    )
    Label(login_screen, text="Please enter details below to login").pack()
    Label(login_screen, text="").pack()

    global username_verify
    global password_verify

    username_verify = StringVar()
    password_verify = StringVar()

    global username_login_entry
    global password_login_entry

    Label(login_screen, text="Username * ").pack()
    username_login_entry = Entry(login_screen, textvariable=username_verify)
    username_login_entry.pack()
    Label(login_screen, text="").pack()
    Label(login_screen, text="Password * ").pack()
    password_login_entry = Entry(login_screen, textvariable=password_verify, show="*")
    password_login_entry.pack()
    Label(login_screen, text="").pack()
    Button(
        login_screen,
        text="Login",
        width=10,
        height=1,
        command=lambda: login_verify(
            my_request, username_verify.get(), password_verify.get()
        ),
    ).pack()

    login_screen.mainloop()


def login_verify(my_request, username, password):
    user_found_flag = False
    for c in credentials:
        if username == c["username"]:
            user_found_flag = True
        if username == c["username"] and password == c["password"]:
            log.info(get_current_date_and_time() + "Login Successful")
            return user_menu(my_request)
    if user_found_flag:
        log.error(get_current_date_and_time() + "Password not recognized")
        return password_not_recognised()
    else:
        log.error(get_current_date_and_time() + "User not found")
        return user_not_found()


def user_menu(my_request):
    login_screen.withdraw()
    messagebox.showinfo("SUCCESS", "Login Successful")
    global user_menu_screen
    user_menu_screen = Toplevel(login_screen)
    user_menu_screen.title("User Menu")
    w = login_screen.winfo_reqwidth()
    h = login_screen.winfo_reqheight()
    ws = login_screen.winfo_screenwidth()
    hs = login_screen.winfo_screenheight()
    x = (ws / 2) - (w / 2)
    y = (hs / 2) - (h / 2)
    user_menu_screen.geometry("+%d+%d" % (x + 100, y + 100))
    user_menu_screen.geometry("300x175")
    if my_request.request_type == "Tx":
        Button(
            user_menu_screen,
            text="Show Time Left Until Next Request",
            command=lambda: show_time(my_request),
        ).pack()
    if my_request.request_type == "Rx":
        Button(
            user_menu_screen,
            text="Show Number of Checks Made",
            command=show_number_of_checks_made,
        ).pack()
    Button(
        user_menu_screen,
        text="Start Service",
        command=lambda: start_service(my_request),
    ).pack()
    Button(
        user_menu_screen, text="Stop Service", command=lambda: stop_service(my_request)
    ).pack()
    Button(user_menu_screen, text="Show Logs", command=show_logs).pack()
    Button(user_menu_screen, text="Clear Logs", command=clear_logs).pack()
    Button(user_menu_screen, text="Close Program", command=close_program).pack()


def reset():
    now = datetime.datetime.now()  # current date and time
    end = now.strftime("%Y-%m-%d %H:%M:%S")
    date1_obj = datetime.datetime.strptime(end, "%Y-%m-%d %H:%M:%S")
    write_service_started_time_to_file(date1_obj.strftime("%Y-%m-%d %H:%M:%S"), 0)
    write_number_of_checks_made(0)


def close_program():
    reset()
    with lock:
        open(log_file_path, "w").close()
        sys.exit()


def start_service(my_request):
    thread = Thread(target=start_app)
    thread.daemon = True
    thread.start()
    send_email(my_request, admin_email, True)
    start_message = "Service has started"
    if my_request.request_type == "Rx":
        log_syslog(start_message)
        th = Thread(target=start_snmp_trap_receiver)
        th.daemon = True
        th.start()
        send_snmp_trap(start_message)
    messagebox.showinfo("SUCCESS", start_message)
    log.info(get_current_date_and_time() + start_message)
    send_request(my_request)


def stop_service(my_request):
    try:
        requests.get("http://127.0.0.1:5000/shutdown")
    except:
        print("Connection max Retries")
    finally:
        if my_request.request_type == "Tx":
            send_email(my_request, admin_email, False)
        reset()
    messagebox.showinfo("SUCCESS", "Service has stopped")
    log.info(get_current_date_and_time() + "Service has stopped")


def send_tx_request(request_string, my_request):
    while True:
        requests.post(request_string)
        time.sleep(my_request.time)


def send_rx_request(request_string, my_request):
    message = None
    k = None
    for i in range(my_request.number_of_checks):
        k = i + 1
        if requests.post(request_string) == 'SUCCESS':
            message = (
                get_current_date_and_time()
                + "File "
                + my_request.file_name_and_extension
                + " was found in collection "
                + my_request.file_location
            )
            log.info(message + " (Check #" + str(k) + ")")
        else:
            message = (
                get_current_date_and_time()
                + "File "
                + my_request.file_name_and_extension
                + " was NOT found in collection "
                + my_request.file_location
            )
            log.error(message + " (Check #" + str(k) + ")")
        write_number_of_checks_made(k)
    log_syslog(message + ", " + str(k) + " times.")
    send_snmp_trap(message + " " + str(k) + " times.")
    send_email(my_request, admin_email, False)


def send_request(my_request):
    request_string = (
        "http://127.0.0.1:"
        + read_port_from_file()
        + "/send_request?request_type="
        + my_request.request_type
        + "&file_name="
        + my_request.file_name_and_extension
        + "&file_location="
        + my_request.file_location
    )
    with lock:
        now = datetime.datetime.now()  # current date and time
        end = now.strftime("%Y-%m-%d %H:%M:%S")
        date1_obj = datetime.datetime.strptime(end, "%Y-%m-%d %H:%M:%S")
        write_service_started_time_to_file(date1_obj.strftime("%Y-%m-%d %H:%M:%S"), 1)
        if my_request.request_type == "Tx":
            thread1 = Thread(target=send_tx_request, args=(request_string, my_request))
            thread1.daemon = True
            thread1.start()
        if my_request.request_type == "Rx":
            thread1 = Thread(target=send_rx_request, args=(request_string, my_request))
            thread1.daemon = True
            thread1.start()


def show_time(my_request):
    d = service_started_time()
    if d["started"]:
        sec = get_seconds_diff(my_request.time)
        messagebox.showinfo("TIME LEFT UNTIL NEXT REQUEST", str(sec) + " Seconds")
    else:
        messagebox.showerror("ERROR", "NO TIME LEFT SINCE SERVICE HAS NOT BEEN STARTED")


def show_number_of_checks_made():
    n = number_of_checks_made()
    if n:
        messagebox.showinfo("NUMBER OF CHECKS MADE", str(n))
        log.info(get_current_date_and_time() + "Number of checks made: " + str(n))
    else:
        messagebox.showerror("ERROR", "NO CHECKS MADE. MAKE SURE YOU START THE SERVICE")
        log.info(get_current_date_and_time() + "No checks made yet.")


def show_logs():
    with open(log_file_path, "r") as f:
        master = tk.Tk()
        master.title(string="Logs")
        text_widget = tk.Text(master, height=50, width=100)
        text_widget.pack()
        text_widget.insert(tk.END, f.read())
        tk.mainloop()


def clear_logs():
    open(log_file_path, "w").close()
    messagebox.showerror("SUCCESS", "Logs have been cleared")


def password_not_recognised():
    messagebox.showerror("ERROR", "Invalid Password")


def user_not_found():
    messagebox.showerror("ERROR", "User Not Found")



import pprint
import typing

import six

T = typing.TypeVar("T")


class Model(object):
    # openapiTypes: The key is attribute name and the
    # value is attribute type.
    openapi_types = {}

    # attributeMap: The key is attribute name and the
    # value is json key in definition.
    attribute_map = {}

    @classmethod
    def from_dict(cls: typing.Type[T], dikt) -> T:
        """Returns the dict as a model"""
        return util.deserialize_model(dikt, cls)

    def to_dict(self, map_keys=False):
        """Returns the model properties as a dict

        :rtype: dict
        """
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            self.add_attr_to_dict(result, map_keys, attr, _)

        if map_keys:
            # replace keys using attribute map in reverse for each response if different
            for item in self.attribute_map.items():
                if item[1] != item[0]:
                    result[item[1]] = result[item[0]]
                    del result[item[0]]

        return result

    def add_attr_to_dict(self, result: dict, map_keys: bool, attr, _):
        value = getattr(self, attr)
        if isinstance(value, list):
            result[attr] = list(
                map(
                    lambda x: x.to_dict(map_keys) if hasattr(x, "to_dict") else x, value
                )
            )
        elif hasattr(value, "to_dict"):
            result[attr] = value.to_dict(map_keys)
        elif isinstance(value, dict):
            result[attr] = dict(
                map(
                    lambda item: (item[0], item[1].to_dict(map_keys))
                    if hasattr(item[1], "to_dict")
                    else item,
                    value.items(),
                )
            )
        else:
            result[attr] = value

    def to_str(self):
        """Returns the string representation of the model

        :rtype: str
        """
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import datetime
import json
from random import randint
import os
import sys

service_started_file_path = sys.path[0].replace("utils", "").replace("/base_library.zip", "") + "/resources/service_started_time.json"
number_of_checks_file_path = sys.path[0].replace("utils", "").replace("/base_library.zip", "") + "/resources/number_of_checks.txt"


def service_started_time():
    with open(
        service_started_file_path
    ) as f:
        return json.load(f)


def write_service_started_time_to_file(time, flag):
    if flag:
        jsonData = {"started": True, "started_time": time}
    else:
        jsonData = {"started": False, "started_time": time}
    with open(
        service_started_file_path,
        "w",
    ) as outfile:
        json.dump(jsonData, outfile, sort_keys=True, indent=4, ensure_ascii=False)


def get_seconds_diff(time_interval):
    d = service_started_time()
    start = d["started_time"]
    now = datetime.datetime.now()  # current date and time
    end = now.strftime("%Y-%m-%d %H:%M:%S")

    date1_obj = datetime.datetime.strptime(end, "%Y-%m-%d %H:%M:%S")
    date2_obj = datetime.datetime.strptime(start, "%Y-%m-%d %H:%M:%S")

    difference_seconds = abs((date1_obj - date2_obj).seconds)
    return time_interval - (difference_seconds % time_interval)


def number_of_checks_made():
    file = open(
        number_of_checks_file_path,
        "r",
    )
    lines = file.read().splitlines()
    return lines[-1]


def write_number_of_checks_made(n):
    file = open(
        number_of_checks_file_path,
        "w",
    )
    file.write(str(n))


def get_current_date_and_time():
    return datetime.datetime.today().strftime(" %Y-%m-%d %H:%M:%S ")


def create_dummy_file(collection_name):
    dummy_file = {
        "file_name": (
            str(randint(0, 8883342)) + get_current_date_and_time() + ".txt"
        ).replace(" ", "_"),
        "file_location": collection_name,
    }
    return dummy_file



import logging
from colorlog import ColoredFormatter

import sys
import os

log_file_path = sys.path[0].replace("common", "").replace("/base_library.zip", "") + "/logs/demo.log"

def get_logger():
    logging.basicConfig(filename=log_file_path)
    LOG_LEVEL = logging.INFO
    LOGFORMAT = (
        "  %(log_color)s%(levelname)-8s%(reset)s | %(log_color)s%(message)s%(reset)s"
    )
    logging.root.setLevel(LOG_LEVEL)
    formatter = ColoredFormatter(LOGFORMAT)
    stream = logging.StreamHandler()
    stream.setLevel(LOG_LEVEL)
    stream.setFormatter(formatter)
    log = logging.getLogger()
    log.setLevel(LOG_LEVEL)
    log.addHandler(stream)
    return log



from PyInstaller.utils.hooks import collect_data_files

datas = collect_data_files('shiboken2', include_py_files=True, subdir='support')
datas += collect_data_files('PySide2', include_py_files=True, subdir='support')



import smtplib
from pysnmp.carrier.asyncio.dgram import udp
from pysnmp.entity import engine, config
from pysnmp.carrier.asyncore.dgram import udp
from pysnmp.entity.rfc3413 import ntfrcv
from filesharing.common.logger import get_logger
from filesharing.utils.current_time import get_current_date_and_time
import syslog
from pysnmp.hlapi import *

log = get_logger()


def create_email_body(my_request, start):
    if my_request.request_type=="Tx":
        if start:
            return (
                "Dear Sir/Madam, \n\n"
                + "A "
                + my_request.request_type
                + " request has been initiated for the file: "
                + my_request.file_name_and_extension
                + " to be stored in table/collection "
                + my_request.file_location
                + ".\n\n"
            )
        else:
            return (
                "Dear Sir/Madam, \n\n"
                + "The "
                + my_request.request_type
                + " request has been processed. File "
                + my_request.file_name_and_extension
                + " has been stored in table/collection "
                + my_request.file_location
                + ".\n\n"
            )
    else:
        if start:
            return (
                "Dear Sir/Madam, \n\n"
                + "A "
                + my_request.request_type
                + " request has been initiated for the file: "
                + my_request.file_name_and_extension
                + " which will be checked if it exists in collection "
                + my_request.file_location
                + ".\n\n"
            )
        else:
            return (
                "Dear Sir/Madam, \n\n"
                + "The "
                + my_request.request_type
                + " request has been processed. File "
                + my_request.file_name_and_extension
                + " has been verified in table/collection "
                + my_request.file_location
                + ".\n\n"
            )


def send_email(my_request, send_to_email: str, start: bool):
    gmail_user = "1thesoftwareengineer1@gmail.com"
    gmail_password = "1developer1"

    sent_from = gmail_user
    to = [send_to_email]
    if start:
        body = create_email_body(my_request, True)
        subject = (
            my_request.request_type
            + ": "
            + my_request.file_name_and_extension
            + " is being processed"
        )
    else:
        body = create_email_body(my_request, False)
        subject = my_request.request_type + " request has completed"
    message = "Subject: {}\n\n{}".format(subject, body)

    try:
        server = smtplib.SMTP_SSL("smtp.gmail.com", 465)
        server.ehlo()
        server.login(gmail_user, gmail_password)
        server.sendmail(sent_from, to, message)
        server.close()
        log.info(get_current_date_and_time() + "Email successfully sent!")
    except:
        log.error(get_current_date_and_time() + "Something went wrong. Email not sent")


def log_syslog(message, info=True):
    if info:
        syslog.syslog(syslog.LOG_INFO, message)
    else:
        syslog.syslog(syslog.LOG_ERR, message)


def cbFun(snmpEngine, stateReference, contextEngineId, contextName, varBinds, cbCtx):
    log.info(get_current_date_and_time() + "Received new Trap message")
    for name, val in varBinds:
        log.info("%s = %s" % (name.prettyPrint(), val.prettyPrint()))


def start_snmp_trap_receiver():
    snmpEngine = engine.SnmpEngine()

    TrapAgentAddress = "192.168.1.14"  # Trap listener address
    port = 163  # trap listener port

    log.info(
        get_current_date_and_time()
        + "Agent is listening SNMP Trap on "
        + TrapAgentAddress
        + " , Port : "
        + str(port)
    )
    log.info(
        "--------------------------------------------------------------------------"
    )
    config.addTransport(
        snmpEngine,
        udp.domainName + (1,),
        udp.UdpTransport().openServerMode(("0.0.0.0", port)),
    )

    # Configure community here
    config.addV1System(snmpEngine, "my-area", "public")
    ntfrcv.NotificationReceiver(snmpEngine, cbFun)

    snmpEngine.transportDispatcher.jobStarted(1)

    try:
        snmpEngine.transportDispatcher.runDispatcher()
    except:
        snmpEngine.transportDispatcher.closeDispatcher()
        raise


def send_snmp_trap(message):
    log.info(get_current_date_and_time() + "New Trap message Sent")
    next(
        sendNotification(
            SnmpEngine(),
            CommunityData("public"),
            UdpTransportTarget(("192.168.1.14", 163)),
            ContextData(),
            "trap",
            [ObjectType(ObjectIdentity("1.3.6.1.2.1.1.1.0"), OctetString(message))],
        )
    )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['filesharing',
 'filesharing.common',
 'filesharing.db',
 'filesharing.domains',
 'filesharing.screens',
 'filesharing.utils']

package_data = \
{'': ['*'], 'filesharing': ['build/*', 'resources/*']}

install_requires = \
['Flask-RESTful>=0.3.9,<0.4.0',
 'Flask>=2.0.1,<3.0.0',
 'black>=21.7b0,<22.0',
 'colorlog>=5.0.1,<6.0.0',
 'dnspython>=2.1.0,<3.0.0',
 'pip>=21.2.4,<22.0.0',
 'pyinstaller>=4.5.1,<5.0.0',
 'pymongo>=3.12.0,<4.0.0',
 'requests>=2.26.0,<3.0.0']

setup_kwargs = {
    'name': 'filesharing',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'YCipriani',
    'author_email': 'yonatancipriani@outlook.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



from filesharing.domains.base_model_ import Model


class Request(Model):
    def __init__(
        self,
        request_type,
        file_name_and_extension,
        file_location,
        time=None,
        number_of_checks=None,
    ):
        self.request_type = request_type
        self.file_name_and_extension = file_name_and_extension
        self.file_location = file_location
        self.time = time
        self.number_of_checks = number_of_checks



import json
import time

from bson import json_util
from simplexml import dumps
from flask import Flask, make_response, request
from flask_restful import Api
from filesharing.db.mongodbDAL import mongodbDAL
from filesharing.screens import login
from filesharing.utils.current_time import (
    get_current_date_and_time,
    create_dummy_file,
    get_seconds_diff,
)
from filesharing.domains.request import Request
from filesharing.common.logger import get_logger
from filesharing.utils.notifications import send_email
from filesharing.utils.port import (
    write_port_to_file,
    read_port_from_file,
    find_free_port,
)
from filesharing.common.globals import admin_email

flask_app = Flask(__name__)
flask_app.use_reloader = False

api = Api(flask_app)


@flask_app.route("/", methods=["GET"])
def home():
    return """<h1>Service is Running</h1>"""


@flask_app.route("/move_file", methods=["POST"])
def move_file():
    if len(request.args.to_dict()) == 3:
        file_name = request.args.get("file_name")
        old_location = request.args.get("old_location")
        new_location = request.args.get("new_location")
        try:
            tx_dal = mongodbDAL("Tx")
            rx_dal = mongodbDAL("Rx")
            tx_dal.move_file(file_name, old_location, new_location)
            rx_dal.move_file(file_name, old_location, new_location)
            return "File " + file_name + " was moved from collection " + old_location + " to collection " + new_location
        except:
            return "Could not preform operation. Make sure file is in the old location specified"
    return "Not enough parameters were passed"


# @flask_app.route("/clear_logs", methods=["POST"])
# def clear_logs():
#     open("/Users/yonatancipriani/PycharmProjects/fileSharing/filesharing/logs/demo.log", "w").close()
#     return "Logs have been cleared"


@flask_app.route("/send_request", methods=["POST"])
def send_request():
    log = get_logger()
    if len(request.args.to_dict()) == 3:
        request_type = request.args.get("request_type")
        file_name = request.args.get("file_name")
        file_location = request.args.get("file_location")
    else:
        if len(request.json) == 3:
            request_type = request.json["request_type"]
            file_name = request.json["file_name"]
            file_location = request.json["file_location"]
        else:
            log.error(
                "Not all of the arguments were provided (request_type, file_name, file_location"
            )
            return "Not all of the arguments were provided (request_type, file_name, file_location"
    file = {
        "file_name": file_name,
        "file_location": file_location,
    }
    dal = mongodbDAL(request_type)
    collection = dal.db.get_collection(file_location)
    if request_type == "Tx":
        rx_dal = mongodbDAL("Rx")
        rx_collection = rx_dal.db.get_collection(file_location)
        dummy_file = create_dummy_file(file_location)
        collection.insert_one(dummy_file)
        rx_collection.insert_one(dummy_file)
        log.info(
            get_current_date_and_time()
            + "Dummy file "
            + dummy_file["file_name"]
            + " was stored in collection "
            + dummy_file["file_location"]
            + "."
        )
        if not dal.find_file_by_collection(file_name, file_location):
            collection.insert_one(file)
            rx_collection.insert_one(file)
            log.info(
                get_current_date_and_time()
                + "File "
                + file_name
                + " was stored in collection "
                + file_location
                + "."
            )
            return "SUCCESS"
        log.error(
            get_current_date_and_time()
            + "File "
            + file_name
            + " already exists in collection "
            + file_location
            + "."
        )
        return "File is already in the collection/table"
    if request_type == "Rx":
        tx_dal = mongodbDAL("Tx")
        if dal.find_file_by_collection(
                file_name, file_location
        ) and tx_dal.find_file_by_collection(file_name, file_location):
            return "SUCCESS"
        else:
            log.error(
                get_current_date_and_time()
                + "File "
                + file_name
                + " was NOT found in collection "
                + file_location
                + "."
            )
            return "File " + file_name + " was NOT found in collection " + file_location + "."


@flask_app.route("/send_rx_request", methods=["POST"])
def send_the_rx_request():
    log = get_logger()
    if len(request.args.to_dict()) == 3:
        file_name = request.args.get("file_name")
        file_location = request.args.get("file_location")
        number_of_checks = request.args.get("number_of_checks")
    else:
        if len(request.json) == 3:
            number_of_checks = request.json["number_of_checks"]
            file_name = request.json["file_name"]
            file_location = request.json["file_location"]
        else:
            log.error(
                "Not all of the arguments were provided (request_type, file_name, file_location)"
            )
            return "Not all of the arguments were provided (request_type, file_name, file_location)"
    tx_dal = mongodbDAL("Tx")
    rx_dal = mongodbDAL("Rx")
    count = 0
    try:
        n = int(number_of_checks)
    except:
        log.error(get_current_date_and_time() + "ERROR: number_of_checks is not a number")
        return "ERROR: number_of_checks is not a number"
    my_request = Request(
        request_type="Rx",
        file_name_and_extension=file_name,
        file_location=file_location,
        number_of_checks=n,
    )
    send_email(my_request, admin_email, True)
    for i in range(n):
        if rx_dal.find_file_by_collection(
                file_name, file_location
        ) and tx_dal.find_file_by_collection(file_name, file_location):
            count += 1
    send_email(my_request, admin_email, False)
    if n != count:
        log.info(get_current_date_and_time() + "File " + file_name + " was NOT found in collection " + file_location + ".")
        return "File " + file_name + " was NOT found in collection " + file_location + "."
    else:
        log.error(get_current_date_and_time() + "File " + file_name + " was found in collection " + file_location + " " + number_of_checks + " times.")
        return "File " + file_name + " was found in collection " + file_location + " " + number_of_checks + " times."


@flask_app.route("/send_tx_request", methods=["POST"])
def send_the_tx_request():
    log = get_logger()
    if len(request.args.to_dict()) == 3:
        file_name = request.args.get("file_name")
        file_location = request.args.get("file_location")
        time_interval = request.args.get("time_interval")
    else:
        if len(request.json) == 3:
            time_interval = request.json["time_interval"]
            file_name = request.json["file_name"]
            file_location = request.json["file_location"]
        else:
            log.error(
                "Not all of the arguments were provided (request_type, file_name, file_location)"
            )
            return "Not all of the arguments were provided (request_type, file_name, file_location)"
    file = {
        "file_name": file_name,
        "file_location": file_location,
    }
    dal = mongodbDAL("Tx")
    collection = dal.db.get_collection(file_location)
    rx_dal = mongodbDAL("Rx")
    rx_collection = rx_dal.db.get_collection(file_location)
    time.sleep(get_seconds_diff(int(time_interval)))
    if not dal.find_file_by_collection(file_name, file_location):
        collection.insert_one(file)
        rx_collection.insert_one(file)
        log.info(
            get_current_date_and_time()
            + "File "
            + file_name
            + " was stored in collection "
            + file_location
            + "."
        )
        return json.loads(json_util.dumps(file))
    log.error(
        get_current_date_and_time()
        + "File "
        + file_name
        + " already exists in collection "
        + file_location
        + "."
    )
    return "File is already in the collection/table"


def shutdown_server():
    func = request.environ.get("werkzeug.server.shutdown")
    if func is None:
        raise RuntimeError("Not running with the Werkzeug Server")
    func()


@flask_app.route("/new_request", methods=["GET"])
def new_request():
    log = get_logger()
    port = read_port_from_file()
    try:
        shutdown_server()
        start_app(port)
    except:
        new_port = find_free_port()
        write_port_to_file(new_port)
        log.info(
            get_current_date_and_time()
            + "New server starting at port number: "
            + str(new_port)
        )
        start_app(port=new_port)
    return "Restarted the Service on Port " + str(port)


@flask_app.route("/shutdown", methods=["GET"])
def shutdown():
    shutdown_server()
    return "Server shutting down..."


@api.representation("application/json")
def output_json(data, code, headers=None):
    resp = make_response(json.dumps({"response": data}), code)
    resp.headers.extend(headers or {})
    return resp


@api.representation("application/xml")
def output_xml(data, code, headers=None):
    resp = make_response(dumps({"response": data}), code)
    resp.headers.extend(headers or {})
    return resp


def start_app(port=5000):
    write_port_to_file(port)
    flask_app.run(port=port)


def main():
    log = get_logger()
    request_type = input("For a Rx request press 0, for a Tx request press 1:\t")
    file_name_and_extension = input("Enter the file name including its extension:\t")
    file_location = input("Enter the file location:\t")
    if int(request_type) == 1:
        time_interval = input("Enter the time interval between requests in seconds:\t")
        request = Request(
            request_type="Tx",
            file_name_and_extension=file_name_and_extension,
            file_location=file_location,
            time=int(time_interval),
        )
    elif int(request_type) == 0:
        n = 0
        while True:
            number_of_checks = input(
                "Enter the number of checks (respond only with numbers no letters):\t"
            )
            try:
                n = int(number_of_checks)
                break
            except ValueError:
                log.error(
                    get_current_date_and_time()
                    + "User entered text instead of only digits"
                )
                print("ERROR: Only NUMBERS are allowed")
                c = input("Do you want to try again? (y/n)")
                if c == "y":
                    continue
                else:
                    exit(0)

        request = Request(
            request_type="Rx",
            file_name_and_extension=file_name_and_extension,
            file_location=file_location,
            number_of_checks=n,
        )
    else:
        log.error(
            get_current_date_and_time()
            + "Only Tx (press 1) and Rx (press 0) requests are allowed"
        )
        return "Only Tx (press 1) and Rx (press 0) requests are allowed"

    login.login(request)


if __name__ == "__main__":
    main()



import json
import os
import sys

from filesharing.common.logger import get_logger
from filesharing.utils.current_time import get_current_date_and_time

credentials_file_path = sys.path[0].replace("common", "").replace("/base_library.zip", "") + "/resources/credentials.json"


def get_all_credentials():
    log = get_logger()
    f = open(
        credentials_file_path
    )
    data = json.load(f)
    if data:
        return data
    else:
        log.info(get_current_date_and_time() + "No credentials found")
